diff --git a/Makefile.pamphlet b/Makefile.pamphlet
index 5cab4a0..25a6672 100644
--- a/Makefile.pamphlet
+++ b/Makefile.pamphlet
@@ -1276,6 +1276,67 @@ all: rootdirs noweb srcsetup lspdir srcdir
 <<clean>>
 
 @
+\subsection{Makefile.vector}
+Annoyingly enough it seems that GCL uses a default extension of .lsp
+rather than .lisp so we add the [[LISP]] variable here. We need to
+depend on the default extension behavior because the system build
+will load either the interpreted or compiled form of a file depending
+on which is available. This varies at different stages of the build.
+
+It turns out that the standard GCL OPTS does not compile with the
+GCL 2.6.8pre version. We changed it from 
+\begin{verbatim}
+@<<GCLOPTS>>
+\end{verbatim}
+to read
+\begin{verbatim}
+@<<GCLOPTS-LOCBFD>>
+\end{verbatim}
+<<Makefile.vector>>=
+# System dependent Makefile for the Intel/Linux platform
+# Platform variable
+PLF=LINUXplatform
+# C compiler flags
+CCF="-O2 -fno-strength-reduce -Wall -D_GNU_SOURCE -D${PLF} -I/usr/X11/include"
+# Loader flags
+LDF=" -L/usr/X11R6/lib ${XLIB}/libXpm.a "
+# C compiler to use
+CC=gcc 
+AWK=gawk
+RANLIB=ranlib
+TOUCH=touch
+TAR=tar
+AXIOMXLROOT=${AXIOM}/compiler
+O=o
+BYE=bye
+LISP=lsp
+DAASE=${SRC}/share
+# where the libXpm.a library lives
+XLIB=/usr/X11R6/lib
+<<GCLOPTS-LOCBFD>>
+<<SRCDIRS>>
+PATCH=patch
+
+ENV=PLF=${PLF} CCF=${CCF} LDF=${LDF} CC=${CC} AWK=${AWK} RANLIB=${RANLIB} \
+    TOUCH=${TOUCH} TAR=${TAR} AXIOMXLROOT=${AXIOMXLROOT} O=${O} BYE=${BYE} \
+    LISP=${LISP} DAASE=${DAASE} XLIB=${XLIB} GCLOPTS=${GCLOPTS} \
+    SRCDIRS=${SRCDIRS} PATCH=${PATCH}
+
+all: rootdirs noweb srcsetup lspdir srcdir
+	@echo 45 Makefile.linux called
+	@echo 46 Environment : ${ENV} 
+	@echo 47 finished system build on `date` | tee >lastBuildDate
+
+<<rootdirs>>
+<<noweb>>
+<<literate commands>>
+<<srcsetup>>
+<<src>>
+<<lsp>>
+<<document>>
+<<clean>>
+
+@
 \subsection{Makefile.redhat72}
 <<Makefile.redhat72>>=
 # System dependent Makefile for the Intel/Linux platform
@@ -2007,6 +2068,81 @@ all: rootdirs noweb srcsetup lspdir srcdir
 <<clean>>
 
 @
+\subsection{Makefile.fedora10}
+On Fedora Core 10 we cannot use the line
+\begin{verbatim}
+  ${XLIB}/libXpm.a
+\end{verbatim}
+to link to the Xpm libraries. Instead We need to use
+\begin{verbatim}
+  -l Xpm
+\end{verbatim}
+These are added onto the end of the LDF variable.
+
+Annoyingly enough it seems that GCL uses a default extension of .lsp
+rather than .lisp so we add the [[LISP]] variable here. We need to
+depend on the default extension behavior because the system build
+will load either the interpreted or compiled form of a file depending
+on which is available. This varies at different stages of the build.
+
+It turns out that the standard GCL OPTS does not compile with the
+GCL 2.6.8pre version. We changed it from 
+\begin{verbatim}
+@<<GCLOPTS>>
+\end{verbatim}
+to read
+\begin{verbatim}
+@<<GCLOPTS-LOCBFD>>
+\end{verbatim}
+
+GCL-2.6.8pre2 will not build successfully on fedora core 10
+so we need to downgrade the GCLVERSION.
+<<Makefile.fedora10>>=
+#GCLVERSION=gcl-2.6.8pre
+# System dependent Makefile for the Intel/Linux platform
+# Platform variable
+PLF=LINUXplatform
+# C compiler flags
+CCF="-O2 -fno-strength-reduce -Wall -D_GNU_SOURCE -D${PLF} -I/usr/X11/include"
+# Loader flags
+LDF=" -L/usr/X11R6/lib -l Xpm "
+# C compiler to use
+CC=gcc 
+AWK=gawk
+RANLIB=ranlib
+TOUCH=touch
+TAR=tar
+AXIOMXLROOT=${AXIOM}/compiler
+O=o
+BYE=bye
+LISP=lsp
+DAASE=${SRC}/share
+# where the libXpm.a library lives
+XLIB=/usr/X11R6/lib
+<<GCLOPTS-LOCBFD>>
+<<SRCDIRS>>
+PATCH=patch
+
+ENV=PLF=${PLF} CCF=${CCF} LDF=${LDF} CC=${CC} AWK=${AWK} RANLIB=${RANLIB} \
+    TOUCH=${TOUCH} TAR=${TAR} AXIOMXLROOT=${AXIOMXLROOT} O=${O} BYE=${BYE} \
+    LISP=${LISP} DAASE=${DAASE} XLIB=${XLIB} GCLOPTS=${GCLOPTS} \
+    SRCDIRS=${SRCDIRS} PATCH=${PATCH}
+
+all: rootdirs noweb srcsetup lspdir srcdir
+	@echo 45 Makefile.linux called
+	@echo 46 Environment : ${ENV} 
+	@echo 47 finished system build on `date` | tee >lastBuildDate
+
+<<rootdirs>>
+<<noweb>>
+<<literate commands>>
+<<srcsetup>>
+<<src>>
+<<lsp>>
+<<document>>
+<<clean>>
+
+@
 \subsection{Makefile.gentoo}
 Annoyingly enough it seems that GCL uses a default extension of .lsp
 rather than .lisp so we add the [[LISP]] variable here. We need to
diff --git a/src/axiom-website/download.html b/src/axiom-website/download.html
index 875d2d3..c6e881a 100644
--- a/src/axiom-website/download.html
+++ b/src/axiom-website/download.html
@@ -126,11 +126,11 @@
        SYSNAME&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
        Nov 2007
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
        Jan 2008
@@ -161,6 +161,11 @@
        Nov 2008
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+       Jan 2009
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -169,10 +174,10 @@
        debian
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -207,6 +212,12 @@
       <a href="downloads/axiom-debian-nov2008-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-debian-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -215,10 +226,10 @@
        Doyen
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -258,10 +269,10 @@
        Doyen Thumbdrive
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
@@ -295,12 +306,12 @@
        fedora5
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-nov2007-src.tgz">src</a>
       <a href="downloads/silver-fedora5-nov182007-bin.tgz">bin</a>
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -345,12 +356,12 @@
        fedora6
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-nov2007-src.tgz">src</a>
       <a href="downloads/silver-fedora6-nov182007-bin.tgz">bin</a>
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -387,6 +398,12 @@
       <a href="downloads/axiom-fedora6-nov2008-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-fedora6-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -395,10 +412,10 @@
        fedora7
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -435,6 +452,12 @@
       <a href="downloads/axiom-fedora7-nov2008-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-fedora7-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -443,12 +466,12 @@
        fedora8
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-nov2007-src.tgz">src</a>
       <a href="downloads/silver-fedora8-nov182007-bin.tgz">bin</a>
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -485,6 +508,12 @@
       <a href="downloads/axiom-fedora8-nov2008-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-fedora8-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -493,10 +522,10 @@
        fedora8-64
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
@@ -534,10 +563,10 @@
        fedora9
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
@@ -570,20 +599,69 @@
       <a href="downloads/axiom-fedora9-nov2008-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-fedora9-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
+
     <tr>
      <td align="left">
       <font face="Helvetica, Arial, sans-serif" size="+1">
-       macosxppc
+       fedora10
       </font>
      </td>
+     <!--td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
      </td>
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-fedora10-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
+    </tr>
+
+    <tr>
+     <td align="left">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+       macosxppc
+      </font>
+     </td>
+     <!--td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td-->
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
       <a href="downloads/silver-macosxppc-jan2008-bin.tgz">bin</a>
       </font>
@@ -618,10 +696,10 @@
        opensuse
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -657,6 +735,12 @@
       <a href="downloads/axiom-nov2008-src.tgz">src</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-opensuse-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -665,10 +749,10 @@
        redhat72
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -713,10 +797,10 @@
        redhat9
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -753,6 +837,12 @@
       <a href="downloads/axiom-redhat9-nov2008-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-redhat9-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -761,10 +851,10 @@
        ubuntu
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/silver-jan2008-src.tgz">src</a>
@@ -801,6 +891,12 @@
       <a href="downloads/axiom-ubuntu-nov2008-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-ubuntu-jan2009-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -809,10 +905,10 @@
        ubuntu64
       </font>
      </td>
-     <td align="center">
+     <!--td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
-     </td>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
@@ -847,6 +943,10 @@
        vector
       </font>
      </td>
+     <!--td align="center">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td-->
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
@@ -869,15 +969,16 @@
      </td>
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-vector-nov2008-bin.tgz">bin</a>
       </font>
      </td>
      <td align="center">
       <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-vector-nov2008-bin.tgz">bin</a>
+      <a href="downloads/axiom-jan2009-src.tgz">src</a>
+      <a href="downloads/axiom-vector-jan2009-bin.tgz">bin</a>
       </font>
      </td>
     </tr>
-
    </tbody>
   </table>
 
@@ -1036,7 +1137,7 @@ apt-get install libxaw7-dev libxdmcp-dev libxext-dev libxmu-dev libxmu-headers
 apt-get install libxpm-dev libxt-dev po-debconf x-dev x11proto-core-dev
 apt-get install x11proto-input-dev x11proto-kb-dev x11proto-xext-dev
 apt-get install xtrans-dev libncurses5-dev libreadline5-dev libsm-dev
-apt-get install libstdc++6-4.1-dev libx11-dev gawk
+apt-get install libstdc++6-4.1-dev libx11-dev gawk texlive-pstricks
 cvs -z3 -d:pserver:anonymous@axiom.cvs.sourceforge.net:/cvsroot/axiom co -P axiom
 cd axiom
 export AXIOM=`pwd`/mnt/debian
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 59cee41..faf325e 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -901,5 +901,7 @@ January 2009 release<br/>
 <a name="latest"/>
 In process, not yet released<br/><br/>
   <hr>
+<a href="patches/20090124.01.tpd.patch">20090124.01.tpd.patch</a>
+download.html update binary download page<br/>
  </body>
 </html>
